@@ -40,6 +40,7 @@
 #include <libart_lgpl/art_affine.h>
 #include <libart_lgpl/art_misc.h>
 #include <libgnomeprint/gnome-print-private.h>
+#include <libgnomeprint/gp-gc-private.h>
 #include <libgnomeprint/gnome-print-transport.h>
 #include <libgnomeprint/gnome-font-private.h>
 #include <libgnomeprint/gnome-print-encode-private.h>
@@ -81,7 +82,6 @@ struct _GnomePrintPs2 {
 	GnomePrintPs2Page *pages;
 	/* Bookkeeping */
 	gint gsave_level;
-	gint ps_level;
 	/* Size of printed area */
 	ArtDRect bbox;
 	/* Buffer */
@@ -94,7 +94,7 @@ struct _GnomePrintPs2Class {
 };
 
 static void gnome_print_ps2_class_init (GnomePrintPs2Class *klass);
-static void gnome_print_ps2_init (GnomePrintPs2 *PS2);
+static void gnome_print_ps2_init (GnomePrintPs2 *ps2);
 static void gnome_print_ps2_finalize (GObject *object);
 
 static gint gnome_print_ps2_construct (GnomePrintContext *ctx);
@@ -145,8 +145,8 @@ gnome_print_ps2_get_type (void)
 static void
 gnome_print_ps2_class_init (GnomePrintPs2Class *klass)
 {
-	GObjectClass *object_class;
 	GnomePrintContextClass *pc_class;
+	GObjectClass *object_class;
 
 	object_class = (GObjectClass *) klass;
 	pc_class = (GnomePrintContextClass *)klass;
@@ -171,7 +171,6 @@ gnome_print_ps2_class_init (GnomePrintPs2Class *klass)
 static void
 gnome_print_ps2_init (GnomePrintPs2 *ps2)
 {
-	ps2->ps_level = 2;
 	ps2->gsave_level = 0;
 	ps2->fonts = NULL;
 	ps2->selectedfont = NULL;
@@ -233,7 +232,6 @@ gnome_print_ps2_construct (GnomePrintContext *ctx)
 	GnomePrintPs2 *ps2;
 	gchar *tmp;
 	gint ret, fd;
-	const GnomePrintUnit *unit;
 
 	ps2 = GNOME_PRINT_PS2 (ctx);
 
@@ -257,12 +255,10 @@ gnome_print_ps2_construct (GnomePrintContext *ctx)
 	ps2->bbox.y0 = 0.0;
 	ps2->bbox.x1 = 210 * 72.0 / 25.4;
 	ps2->bbox.y1 = 297 * 72.0 / 25.4;
-	if (gnome_print_config_get_length (ctx->config, GNOME_PRINT_KEY_PAPER_WIDTH, &ps2->bbox.x1, &unit)) {
-		gnome_print_convert_distance (&ps2->bbox.x1, unit, GNOME_PRINT_PS_UNIT);
-	}
-	if (gnome_print_config_get_length (ctx->config, GNOME_PRINT_KEY_PAPER_HEIGHT, &ps2->bbox.y1, &unit)) {
-		gnome_print_convert_distance (&ps2->bbox.y1, unit, GNOME_PRINT_PS_UNIT);
-	}
+	
+	gnome_print_config_get_length (ctx->config, GNOME_PRINT_KEY_PAPER_WIDTH,  &ps2->bbox.x1, NULL);
+	gnome_print_config_get_length (ctx->config, GNOME_PRINT_KEY_PAPER_HEIGHT, &ps2->bbox.y1, NULL);
+	
 	if (ctx->config) {
 		gdouble pp2pa[6];
 		art_affine_identity (pp2pa);
@@ -332,18 +328,16 @@ gnome_print_ps2_fill (GnomePrintContext *ctx, const ArtBpath *bpath, ArtWindRule
 
 	ps2 = GNOME_PRINT_PS2 (ctx);
 
-	ret = gnome_print_ps2_set_color (ps2);
-	g_return_val_if_fail (ret >= 0, ret);
-
-	ret = gnome_print_ps2_print_bpath (ps2, bpath);
-	g_return_val_if_fail (ret >= 0, ret);
+	ret += gnome_print_ps2_set_color (ps2);
+	ret += gnome_print_ps2_print_bpath (ps2, bpath);
 
 	if (rule == ART_WIND_RULE_NONZERO) {
-		ret = gnome_print_ps2_fprintf (ps2, "f" EOL);
+		ret += gnome_print_ps2_fprintf (ps2, "f" EOL);
 	} else {
-		ret = gnome_print_ps2_fprintf (ps2, "f*" EOL);
+		ret += gnome_print_ps2_fprintf (ps2, "f*" EOL);
 	}
 
+	g_return_val_if_fail (ret >= 0, ret);
 	/* Update bbox */
 
 
@@ -354,18 +348,15 @@ static gint
 gnome_print_ps2_stroke (GnomePrintContext *ctx, const ArtBpath *bpath)
 {
 	GnomePrintPs2 *ps2;
-	gint ret;
+	gint ret = 0;
 
 	ps2 = GNOME_PRINT_PS2 (ctx);
 
-	ret = gnome_print_ps2_set_color (ps2);
-	g_return_val_if_fail (ret >= 0, ret);
-	ret = gnome_print_ps2_set_line (ps2);
-	g_return_val_if_fail (ret >= 0, ret);
-	ret = gnome_print_ps2_set_dash (ps2);
-	g_return_val_if_fail (ret >= 0, ret);
-
-	ret = gnome_print_ps2_print_bpath (ps2, bpath);
+	ret += gnome_print_ps2_set_color (ps2);
+	ret += gnome_print_ps2_set_line (ps2);
+	ret += gnome_print_ps2_set_dash (ps2);
+	ret += gnome_print_ps2_print_bpath (ps2, bpath);
+	
 	g_return_val_if_fail (ret >= 0, ret);
 
 	ret = gnome_print_ps2_fprintf (ps2, "S" EOL);
@@ -377,30 +368,25 @@ static int
 gnome_print_ps2_image (GnomePrintContext *pc, const gdouble *ctm, const guchar *px, gint w, gint h, gint rowstride, gint ch)
 {
 	GnomePrintPs2 *ps2;
-	gint ret;
 	gchar *hex;
 	gint hex_size;
+	gint ret = 0;
 	gint r;
 
 	ps2 = GNOME_PRINT_PS2 (pc);
 
-	ret = gnome_print_ps2_fprintf (ps2, "q" EOL);
-	g_return_val_if_fail (ret >= 0, ret);
-	ret = gnome_print_ps2_fprintf (ps2, "[%g %g %g %g %g %g]cm" EOL, ctm[0], ctm[1], ctm[2], ctm[3], ctm[4], ctm[5]);
-	g_return_val_if_fail (ret >= 0, ret);
+	ret += gnome_print_ps2_fprintf (ps2, "q" EOL);
+	ret += gnome_print_ps2_fprintf (ps2, "[%g %g %g %g %g %g]cm" EOL, ctm[0], ctm[1], ctm[2], ctm[3], ctm[4], ctm[5]);
 
 	/* Image commands */
-	ret = gnome_print_ps2_fprintf (ps2, "/buf %d string def" EOL "%d %d 8" EOL, w * ch, w, h);
-	g_return_val_if_fail (ret >= 0, ret);
-	ret = gnome_print_ps2_fprintf (ps2, "[%d 0 0 %d 0 %d]" EOL, w, -h, h);
-	g_return_val_if_fail (ret >= 0, ret);
-	ret = gnome_print_ps2_fprintf (ps2, "{ currentfile buf readhexstring pop }\n");
-	g_return_val_if_fail (ret >= 0, ret);
+	ret += gnome_print_ps2_fprintf (ps2, "/buf %d string def" EOL "%d %d 8" EOL, w * ch, w, h);
+	ret += gnome_print_ps2_fprintf (ps2, "[%d 0 0 %d 0 %d]" EOL, w, -h, h);
+	ret += gnome_print_ps2_fprintf (ps2, "{ currentfile buf readhexstring pop }\n");
 
 	if (ch == 1) {
-		ret = gnome_print_ps2_fprintf (ps2, "image" EOL);
+		ret += gnome_print_ps2_fprintf (ps2, "image" EOL);
 	} else {
-		ret = gnome_print_ps2_fprintf (ps2, "false %d colorimage" EOL, ch);
+		ret += gnome_print_ps2_fprintf (ps2, "false %d colorimage" EOL, ch);
 	}
 	g_return_val_if_fail (ret >= 0, ret);
 
@@ -408,15 +394,14 @@ gnome_print_ps2_image (GnomePrintContext *pc, const gdouble *ctm, const guchar *
 
 	for (r = 0; r < h; r++) {
 		hex_size = gnome_print_encode_hex (px + r * rowstride, hex, w * ch);
-		ret = fwrite (hex, sizeof (gchar), hex_size, ps2->buf);
-		g_return_val_if_fail (ret >= 0, ret);
-		ret = gnome_print_ps2_fprintf (ps2, EOL);
-		g_return_val_if_fail (ret >= 0, ret);
+		ret += fwrite (hex, sizeof (gchar), hex_size, ps2->buf);
+		ret += gnome_print_ps2_fprintf (ps2, EOL);
 	}
 
 	g_free (hex);
 	
 	ret = gnome_print_ps2_fprintf (ps2, "Q" EOL);
+	
 	g_return_val_if_fail (ret >= 0, ret);
 
 	return GNOME_PRINT_OK;
@@ -525,49 +510,40 @@ gnome_print_ps2_glyphlist (GnomePrintContext *pc, const gdouble *a, GnomeGlyphLi
 static gint
 gnome_print_ps2_beginpage (GnomePrintContext *pc, const guchar *name)
 {
+	GnomePrintPs2Page *page;
 	GnomePrintPs2 *ps2;
-	GnomePrintPs2Page *p;
 	gint number;
-	gint ret;
+	gint ret = 0;
 
 	ps2 = GNOME_PRINT_PS2 (pc);
 
 	number = ps2->pages ? ps2->pages->number : 0;
 
-	p = g_new (GnomePrintPs2Page, 1);
-	p->next = ps2->pages;
-	p->name = g_strdup (name);
-	p->number = number + 1;
-	p->shown = FALSE;
-	p->usedfonts = NULL;
+	page = g_new (GnomePrintPs2Page, 1);
+	page->next = ps2->pages;
+	page->name = g_strdup (name);
+	page->number = number + 1;
+	page->shown = FALSE;
+	page->usedfonts = NULL;
 
-	ps2->pages = p;
+	ps2->pages = page;
 
 	ps2->selectedfont = NULL;
 	ps2->private_color_flag = GP_GC_FLAG_UNSET;
 
-	ret = gnome_print_ps2_fprintf (ps2, "%%%%Page: %s %d" EOL, name, p->number);
-	g_return_val_if_fail (ret >= 0, ret);
-	ret = gnome_print_ps2_fprintf (ps2, "%%%%PageResources: (atend)" EOL);
-	g_return_val_if_fail (ret >= 0, ret);
+	ret += gnome_print_ps2_fprintf (ps2, "%%%%Page: %s %d" EOL, name, page->number);
+	ret += gnome_print_ps2_fprintf (ps2, "%%%%PageResources: (atend)" EOL);
 
-	ret = gnome_print_newpath (pc);
-	g_return_val_if_fail (ret >= 0, ret);
-	ret = gnome_print_moveto (pc, 0.0, 0.0);
-	g_return_val_if_fail (ret >= 0, ret);
-	ret = gnome_print_lineto (pc, ps2->bbox.x1, 0.0);
-	g_return_val_if_fail (ret >= 0, ret);
-	ret = gnome_print_lineto (pc, ps2->bbox.x1, ps2->bbox.y1);
-	g_return_val_if_fail (ret >= 0, ret);
-	ret = gnome_print_lineto (pc, 0.0, ps2->bbox.y1);
-	g_return_val_if_fail (ret >= 0, ret);
-	ret = gnome_print_lineto (pc, 0.0, 0.0);
-	g_return_val_if_fail (ret >= 0, ret);
-	ret = gnome_print_closepath (pc);
-	g_return_val_if_fail (ret >= 0, ret);
-	ret = gnome_print_clip (pc);
-	g_return_val_if_fail (ret >= 0, ret);
-	ret = gnome_print_newpath (pc);
+	ret += gnome_print_newpath (pc);
+	ret += gnome_print_moveto (pc, 0.0, 0.0);
+	ret += gnome_print_lineto (pc, ps2->bbox.x1, 0.0);
+	ret += gnome_print_lineto (pc, ps2->bbox.x1, ps2->bbox.y1);
+	ret += gnome_print_lineto (pc, 0.0, ps2->bbox.y1);
+	ret += gnome_print_lineto (pc, 0.0, 0.0);
+	ret += gnome_print_closepath (pc);
+	ret += gnome_print_clip (pc);
+	ret += gnome_print_newpath (pc);
+	
 	g_return_val_if_fail (ret >= 0, ret);
 
 	return GNOME_PRINT_OK;
@@ -578,37 +554,37 @@ static gint
 gnome_print_ps2_showpage (GnomePrintContext *pc)
 {
 	GnomePrintPs2 *ps2;
-	gint ret;
+	gint ret = 0;
 
 	ps2 = GNOME_PRINT_PS2 (pc);
 
 	if (ps2->pages)
 		ps2->pages->shown = TRUE;
+	
 	ps2->selectedfont = NULL;
 	ps2->private_color_flag = GP_GC_FLAG_UNSET;
 
-	ret = gnome_print_ps2_fprintf (ps2, "SP" EOL);
-	g_return_val_if_fail (ret >= 0, ret);
-	ret = gnome_print_ps2_fprintf (ps2, "%%%%PageTrailer" EOL);
-	g_return_val_if_fail (ret >= 0, ret);
-	ret = gnome_print_ps2_fprintf (ps2, "%%%%PageResources: procset gnome-print-procs-%s" EOL, VERSION);
-	g_return_val_if_fail (ret >= 0, ret);
+	ret += gnome_print_ps2_fprintf (ps2, "SP" EOL);
+	ret += gnome_print_ps2_fprintf (ps2, "%%%%PageTrailer" EOL);
+	ret += gnome_print_ps2_fprintf (ps2, "%%%%PageResources: procset gnome-print-procs-%s" EOL, VERSION);
+
 	while (ps2->pages->usedfonts) {
 		GnomePrintPs2Font *font;
 		font = ps2->pages->usedfonts->data;
-		ret = gnome_print_ps2_fprintf (ps2, "%%%%+ font %s" EOL, font->pso->encodedname);
-		g_return_val_if_fail (ret >= 0, ret);
+		ret += gnome_print_ps2_fprintf (ps2, "%%%%+ font %s" EOL, font->pso->encodedname);
 		ps2->pages->usedfonts = g_slist_remove (ps2->pages->usedfonts, ps2->pages->usedfonts->data);
 	}
 
+	g_return_val_if_fail (ret >= 0, ret);
+	
 	return GNOME_PRINT_OK;
 }
 
 static gint
 gnome_print_ps2_close (GnomePrintContext *pc)
 {
+	GnomePrintPs2Font *font;
 	GnomePrintPs2 *ps2;
-	GnomePrintPs2Font *f;
 	gchar *date;
 	gchar *orientation;
 	gchar *name;
@@ -671,8 +647,8 @@ gnome_print_ps2_close (GnomePrintContext *pc)
 	
 	gnome_print_transport_printf (pc->transport, "%%%%DocumentSuppliedResources: procset pnome-print-procs-%s" EOL, VERSION);
 	/* %%DocumentSuppliedResources: */
-	for (f = ps2->fonts; f != NULL; f = f->next) {
-		gnome_print_transport_printf (pc->transport, "%%%%+ font %s" EOL, f->pso->encodedname);
+	for (font = ps2->fonts; font != NULL; font = font->next) {
+		gnome_print_transport_printf (pc->transport, "%%%%+ font %s" EOL, font->pso->encodedname);
 	}
 	gnome_print_transport_printf (pc->transport, "%%%%EndComments" EOL);
 	g_free (date);
@@ -707,10 +683,10 @@ gnome_print_ps2_close (GnomePrintContext *pc)
 	gnome_print_transport_printf (pc->transport, "/Orientation %d" EOL, 0); /* FIXME: real orientation */
 	gnome_print_transport_printf (pc->transport, ">> setpagedevice" EOL);
 	/* Download fonts */
-	for (f = ps2->fonts; f != NULL; f = f->next) {
-		gnome_font_face_pso_ensure_buffer (f->pso);
-		gnome_print_transport_printf (pc->transport, "%%%%BeginResource: font %s" EOL, f->pso->encodedname);
-		gnome_print_transport_write (pc->transport, f->pso->buf, f->pso->length);
+	for (font = ps2->fonts; font != NULL; font = font->next) {
+		gnome_font_face_pso_ensure_buffer (font->pso);
+		gnome_print_transport_printf (pc->transport, "%%%%BeginResource: font %s" EOL, font->pso->encodedname);
+		gnome_print_transport_write (pc->transport, font->pso->buf, font->pso->length);
 		gnome_print_transport_printf (pc->transport, "%%%%EndResource" EOL);
 	}
 	gnome_print_transport_printf (pc->transport, "%%%%EndSetup" EOL);
@@ -730,6 +706,7 @@ gnome_print_ps2_close (GnomePrintContext *pc)
 		g_warning ("Error unlinking buffer");
 	}
 	ps2->bufname = NULL;
+	/* END: Write buffer */
 
 	gnome_print_transport_printf (pc->transport, "%%%%Trailer" EOL);
 	gnome_print_transport_printf (pc->transport, "%%%%EOF" EOL);
@@ -762,10 +739,10 @@ gnome_print_ps2_set_line (GnomePrintPs2 *ps2)
 		return 0;
 
 	ret = gnome_print_ps2_fprintf (ps2, "%g w %i J %i j %g M" EOL,
-			      gp_gc_get_linewidth (ctx->gc),
-			      gp_gc_get_linecap (ctx->gc),
-			      gp_gc_get_linejoin (ctx->gc),
-			      gp_gc_get_miterlimit (ctx->gc));
+				       gp_gc_get_linewidth (ctx->gc),
+				       gp_gc_get_linecap (ctx->gc),
+				       gp_gc_get_linejoin (ctx->gc),
+				       gp_gc_get_miterlimit (ctx->gc));
 	gp_gc_set_line_flag (ctx->gc, GP_GC_FLAG_CLEAR);
 
 	return ret;
@@ -776,7 +753,7 @@ gnome_print_ps2_set_dash (GnomePrintPs2 *ps2)
 {
 	GnomePrintContext *ctx;
 	const ArtVpathDash *dash;
-	gint ret, i;
+	gint ret = 0, i;
 
 	ctx = GNOME_PRINT_CONTEXT (ps2);
 
@@ -784,11 +761,14 @@ gnome_print_ps2_set_dash (GnomePrintPs2 *ps2)
 		return 0;
 
 	dash = gp_gc_get_dash (ctx->gc);
-	ret = gnome_print_ps2_fprintf (ps2, "[");
-	for (i = 0; i < dash->n_dash; i++) ret += gnome_print_ps2_fprintf (ps2, " %g", dash->dash[i]);
+	ret += gnome_print_ps2_fprintf (ps2, "[");
+	for (i = 0; i < dash->n_dash; i++)
+		ret += gnome_print_ps2_fprintf (ps2, " %g", dash->dash[i]);
 	ret += gnome_print_ps2_fprintf (ps2, "]%g d" EOL, dash->n_dash > 0 ? dash->offset : 0.0);
 	gp_gc_set_dash_flag (ctx->gc, GP_GC_FLAG_CLEAR);
 
+	g_return_val_if_fail (ret >= 0, ret);
+		
 	return ret;
 }
 
@@ -801,7 +781,7 @@ gnome_print_ps2_set_color_private (GnomePrintPs2 *ps2, gdouble r, gdouble g, gdo
 	ctx = GNOME_PRINT_CONTEXT (ps2);
 
 	if ((ps2->private_color_flag == GP_GC_FLAG_CLEAR) && (r == ps2->r) && (g == ps2->g) && (b == ps2->b))
-		return 0;
+		return GNOME_PRINT_OK;
 
 	ret = gnome_print_ps2_fprintf (ps2, "%.3g %.3g %.3g rg" EOL, r, g, b);
 
@@ -810,50 +790,54 @@ gnome_print_ps2_set_color_private (GnomePrintPs2 *ps2, gdouble r, gdouble g, gdo
 	ps2->b = b;
 	ps2->private_color_flag = GP_GC_FLAG_CLEAR;
 
+	g_return_val_if_fail (ret >= 0, ret);
+	
 	return ret;
 }
 
 static gint
-gnome_print_ps2_set_font_private (GnomePrintPs2 *ps2, const GnomeFont *font)
+gnome_print_ps2_set_font_private (GnomePrintPs2 *ps2, const GnomeFont *gnome_font)
 {
 	const GnomeFontFace *face;
-	GnomePrintPs2Font *f;
-	gint ret;
+	GnomePrintPs2Font *font;
+	gint ret = 0;
 	GSList *l;
 
-	if (ps2->selectedfont && (ps2->selectedfont->face == font->face) && (ps2->selectedfont->currentsize = font->size))
+	if (ps2->selectedfont && (ps2->selectedfont->face == gnome_font->face) && (ps2->selectedfont->currentsize = gnome_font->size))
 		return 0;
 
-	face = gnome_font_get_face (font);
+	face = gnome_font_get_face (gnome_font);
 
-	for (f = ps2->fonts; f != NULL; f = f->next) {
-		if (f->face == face)
+	for (font = ps2->fonts; font != NULL; font = font->next) {
+		if (font->face == face)
 			break;
 	}
-	if (!f) {
+	if (!font) {
 		/* No entry, so create one */
-		f = g_new (GnomePrintPs2Font, 1);
-		f->next = ps2->fonts;
-		ps2->fonts = f;
-		f->face = (GnomeFontFace *) face;
+		font = g_new (GnomePrintPs2Font, 1);
+		font->next = ps2->fonts;
+		ps2->fonts = font;
+		font->face = (GnomeFontFace *) face;
 		gnome_font_face_ref (face);
-		f->pso = gnome_font_face_pso_new ((GnomeFontFace *) face, NULL);
-		g_return_val_if_fail (f->pso != NULL, GNOME_PRINT_ERROR_UNKNOWN);
+		font->pso = gnome_font_face_pso_new ((GnomeFontFace *) face, NULL);
+		g_return_val_if_fail (font->pso != NULL, GNOME_PRINT_ERROR_UNKNOWN);
 	}
 
 	for (l = ps2->pages->usedfonts; l != NULL; l = l->next) {
-		if ((GnomePrintPs2Font *) l->data == f)
+		if ((GnomePrintPs2Font *) l->data == font)
 			break;
 	}
 	if (!l) {
-		ps2->pages->usedfonts = g_slist_prepend (ps2->pages->usedfonts, f);
+		ps2->pages->usedfonts = g_slist_prepend (ps2->pages->usedfonts, font);
 	}
 
-	ret = gnome_print_ps2_fprintf (ps2, "/%s FF %g F" EOL, f->pso->encodedname, gnome_font_get_size (font));
+	ret += gnome_print_ps2_fprintf (ps2, "/%s FF %g F" EOL, font->pso->encodedname, gnome_font_get_size (gnome_font));
 
-	f->currentsize = font->size;
-	ps2->selectedfont = f;
+	font->currentsize = gnome_font->size;
+	ps2->selectedfont = font;
 
+	g_return_val_if_fail (ret >= 0, ret);
+	
 	return ret;
 }
 
