@@ -1,34 +1,33 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/*
+ *  gnome-print-unit.c: Unit utility functio
+ *
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public License
+ *  as published by the Free Software Foundation; either version 2 of
+ *  the License, or (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *  Authors:
+ *    Dirk Luetjens <dirk@luedi.oche.de>
+ *    Yves Arrouye <Yves.Arrouye@marin.fdn.fr>
+ *    Lauris Kaplinski <lauris@ximian.com>
+ *
+ *  Copyright (C) 1998 The Free Software Foundation and 2001-2202 Ximian, Inc.
+ *
+ */
+
 #ifndef __GNOME_PRINT_UNIT_H__
 #define __GNOME_PRINT_UNIT_H__
 
-/*
- * GnomePrintUnit
- *
- * It is pure convenience stuff, that hopefully meakes the life
- * easier for someone
- *
- * Copyright (C) 1998 the Free Software Foundation and Ximian, Inc.
- *
- * Authors:
- *   Dirk Luetjens <dirk@luedi.oche.de>
- *   Yves Arrouye <Yves.Arrouye@marin.fdn.fr>
- *   Lauris Kaplinski <lauris@ximian.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc.,  59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
- */
-
 #include <glib.h>
 
 G_BEGIN_DECLS
@@ -57,7 +56,7 @@ typedef struct _GnomePrintUnit GnomePrintUnit;
  * The base absolute unit is 1/72th of an inch (we are gnome PRINT, so sorry SI)
  */
 
-enum {
+typedef enum {
 	GNOME_PRINT_UNIT_DIMENSIONLESS = (1 << 0), /* For percentages and like */
 	GNOME_PRINT_UNIT_ABSOLUTE = (1 << 1), /* Real world distances - i.e. mm, cm... */
 	GNOME_PRINT_UNIT_DEVICE = (1 << 2), /* Semi-real device-dependent distances i.e. pixels */
@@ -86,14 +85,13 @@ struct _GnomePrintUnit {
 /* Base units are the ones used by gnome-print and paper descriptions */
 
 #define GNOME_PRINT_PS_UNIT (gnome_print_unit_get_identity (GNOME_PRINT_UNIT_ABSOLUTE))
+#define GNOME_PRINT_UNITS_ALL (GNOME_PRINT_UNIT_DIMENSIONLESS | GNOME_PRINT_UNIT_ABSOLUTE | GNOME_PRINT_UNIT_DEVICE | GNOME_PRINT_UNIT_USERSPACE)
 
 const GnomePrintUnit *gnome_print_unit_get_identity (guint base);
 const GnomePrintUnit *gnome_print_unit_get_default (void);
 const GnomePrintUnit *gnome_print_unit_get_by_name (const guchar *name);
 const GnomePrintUnit *gnome_print_unit_get_by_abbreviation (const guchar *abbreviation);
 
-#define GNOME_PRINT_UNITS_ALL (GNOME_PRINT_UNIT_DIMENSIONLESS | GNOME_PRINT_UNIT_ABSOLUTE | GNOME_PRINT_UNIT_DEVICE | GNOME_PRINT_UNIT_USERSPACE)
-
 GList *gnome_print_unit_get_list (guint bases);
 void gnome_print_unit_free_list (GList *units);
 
