@@ -96,6 +96,8 @@ gpa_root_init (GPARoot *root)
 	root_instance = GPA_NODE (root);
 
 	root->media = NULL;
+	root->vendors = NULL;
+	root->printers = NULL;
 
 #if 0
 	root->vendors = gpa_node_attach (GPA_NODE (root), GPA_NODE (gpa_vendor_list_load ()));
@@ -168,7 +170,7 @@ gpa_root_finalize (GObject *object)
 	}
 
 	if (root->printers) {
-		/* Disconnect vendors */
+		/* Disconnect printers */
 		g_signal_handlers_disconnect_by_func (G_OBJECT (root->printers), gpa_root_printers_modified, root);
 		g_object_weak_unref (G_OBJECT (root->printers), gpa_root_printers_gone, root);
 		root->printers = NULL;
@@ -193,8 +195,6 @@ gpa_root_get_child (GPANode *node, GPANode *ref)
 
 	root = GPA_ROOT (node);
 
-	g_return_val_if_fail (root->printers != NULL, NULL);
-	
 	if (!ref) {
 		if (root->vendors) {
 			return gpa_node_ref (root->vendors);
